##Andrew Osborne August 2024##
## Examples for EDE models with mixed-certainty data, and reliability vectors
##Derived from code provided as supporting information from;
#A fast re-sampling method for using reliability ratings of sightings with extinction-date estimators
#Brook B., Buettel J.and Jarić I.
#Ecology, June 2019
"https://doi.org/10.1002/ecy.2787"

#Code in supplemental information
#The functions script 'ede_functions.r' is required to run this code; needs to be in the same directory as 'Chat_Moss_Leps_ede.R'
"https://esajournals.onlinelibrary.wiley.com/action/downloadSupplement?doi=10.1002%2Fecy.2787&file=ecy2787-sup-0002-DataS1.zip"

##working directory needs to be specified
dev.off()
setwd("~/Desktop/PC_Folders/LHB/Manuscripts/ChatMoss_Ecosystem/ESA/ecy2787-sup-0002-datas")
list.files()

rm(list=ls()); options(scipen=999,warn=-1) 
require(parallel) # required for parallel computing
detectCores()
nCores=detectCores()
source('ede_functions.r')  # put this in the working directory
#################################################################################

### Load Lep data based on physical=pinned specimen (identification almost certain), 
#expert=observation of live insect (presumed reliable as close observation by non-casual observer)
#The year/date when presence was recorded in each area is input into the algorithm.
#Hence a year/date may entered multiple times if the species was recorded in more than one area in a single year.
#But multiple individual records, in the same area, in a single year, are only entered as one year/date. 
load.Lep.data <- function(eg="IW",rel=c(0.99,0.9)) {
  eg.dat <- list()

  if(eg=="FW") { # fen wainscot
    eg.dat$year.pe <- c()
    eg.dat$pe <- rep(rel[1],length(eg.dat$year.pe)) # physical
    eg.dat$year.ie <- c(1903,1940)
    eg.dat$ie <- rep(rel[2],length(eg.dat$year.ie)) # expert
  }
  else if(eg=="MTB") { # Manc treble-bar moth
    eg.dat$year.pe <- c(1894,1898,1908,1910,1912)
    eg.dat$pe <- rep(rel[1],length(eg.dat$year.pe)) # physical
    eg.dat$year.ie <- c(1846,1862,1875,1882,1882,1894,1897,1898,1908,1912)
    eg.dat$ie <- rep(rel[2],length(eg.dat$year.ie)) # expert
  }
  else if(eg=="LHB") { # large heath butterfly
    eg.dat$year.pe <- c(1897,1899)
    eg.dat$pe <- rep(rel[1],length(eg.dat$year.pe)) # physical
    eg.dat$year.ie <- c(1857,1896,1896,1926)
    eg.dat$ie <- rep(rel[2],length(eg.dat$year.ie)) # expert
  }
  else if(eg=="PBG") { # purple-bordered gold moth
    eg.dat$year.pe <- c()
    eg.dat$pe <- rep(rel[1],length(eg.dat$year.pe)) # physical
    eg.dat$year.ie <- c(1846,1859,1859,1959,1886,1890,1900,1964)
    eg.dat$ie <- rep(rel[2],length(eg.dat$year.ie)) # expert
  }
  if(eg=="BP") { # bilberry pug
    eg.dat$year.pe <- c()
    eg.dat$pe <- rep(rel[1],length(eg.dat$year.pe)) # physical
    eg.dat$year.ie <- c(1862)
    eg.dat$ie <- rep(rel[2],length(eg.dat$year.ie)) # expert
  }
  
  return(eg.dat)
}

##########################################
#### ede-method ####
##From Brook.B and Jarić. I##
##########################################

## Inferring extinction with mixed-reliability data using resampling - BW Brook, Mar 2019 #############################

### Select sighting record data, reliability vector, observation year and upper confidence bound ######################
pv <- c(0.99,0.90)# physical=pinned specimen, expert=observation of live insect:
sp <- "MTB" # Specifiy species sighting record;  FW, MTB, LHB, PBG, BP
obs.year <- 2020; a <- 0.05 # set observation year and alpha for upper confidence interval

### Pre-process and display sighting record data ######################################################################
es <- load.Lep.data(eg=sp,rel=pv) # load example data and impose reliability vector
dat <- dmy.cprob(data.frame(year=c(es$year.pe,es$year.ie),prob=c(es$pe,es$ie))) # pre-process data.  
#Presence at individual sites is condensed to presence within each year.
ma.pd(dat) # plot moving-average of 1-rel as indication of persistence, based on a window of n sightings

### Estimated Date of Extinction (EDE) ########################################################
##estimates on mixed-certainty data for BBJ18 and JR14 ##
jr.2014(dat, ey=obs.year, m="so93") # Jaric & Roberts 2014 method for m = "so93", "mc06", "ss89" or "LAD" (default)

ede <- "ole" # Current methods are "rw64", so93", "mc06" and "ole" (f must take sighting record and return TE)
set.seed(42)
bbj.2018(dat, iter=10000, ey=obs.year, m=ede) # BBJ18 (weighted resampling) method: m = pre-defined EDE function to use (default: "LAD")

mte.yr <- bbj.mte_yr(dat,m=ede,jk=T); mte.yr # check sensitivity of cut-off by year, or jackknifing each obs
#######################################################################################################################

#### Estimate Extinction Date From Single Recording ####
##From Roberts. D and Jarić. I##

#Roberts, David L & Jarić, Ivan. 2020. Inferring the extinction of species known only from a single specimen. Oryx 54: 161-166.
"https://doi.org/10.1017/S0030605319000590"
##########################################

setwd("~/Desktop/PC_Folders/LHB/Manuscripts/ChatMoss_Ecosystem/Supplemental_Data")
list.files(pattern=".csv")

Leps <- read.csv("CM_2.5kBuffer_AllSpecies.csv")
names(Leps)

nrow(Leps) #Total number of Lep recordings 1841-2020 49,156

####

#fen wainscot last recorded 1940 (only one previous recording in 1903)

#recordings (detection effort) up to 1940
nrow(subset(Leps,Start.date.year <1940 ))#236

#proportion of the effort prior to the specimen being collected 
#to the total effort over the whole collection period
236/49156 #ratio=0.00480
#Probable that fen winscot is extinct p=0.005

####

#bilberry pug last recorded 1862 

#recordings prior to 1862
nrow(subset(Leps,Start.date.year < 1862 ))#85

#proportion of the effort prior to the specimen being collected 
#to the total effort over the whole collection period
85/49156 #(p=0.001729)
#Probable that bilberry pug is extinct p=0.002

###################################################################

####Chi-sq####

###to test the significance of the apparent reduction in records of the
#presence of indicator species after 1919

#Total of 28 recordings of presence across sites within the Chat Moss area
# between years 1841 and 1919 inclusive = 79
# between years 1920 and 1919 inclusive = 100
#total number of years between 1841 and 2019 
#inclusive= 179

##input OBSERVED and EXPECTED data

#From Appendix 1, table of recordings of presence
#1841-1919; 25 Observed recordings of presence
#1920-2019; 3 Observed recordings of presence
#1841-2019; total of 28 Observed recordings of presence
#Expected during the first part of the series 1841-1919
29*(79/179) #12.799
#Expected during the second part of the series 1920-2019
29*(100/179) #16.201

##input OBSERVED and EXPECTED data
chi<-as.table(rbind(c(26,12.799),c(3,16.201)))
dimnames(chi) <- list(Date = c("Pre-1920","1920-Onwards"), Present = c("Observed", "Expected"))   #labelling Chisq axis
##view chi table
chi
##perform chi-squared test
#(use fisher.test if data counts<10 ie single figures)
chi.scores<-chisq.test(chi)
##test result
chi.scores #p=0.001021





